#!/bin/sh
#
# /etc/firewall/start
# EnGarde Secure Linux firewall startup script
#
# Copyright 2000-2003, Guardian Digital Inc.
# $Id: default.sh,v 1.1.1.1 2003/03/05 14:43:18 rwm Exp $
#

###
###  Read our configuration file.
###
. /etc/firewall/firewall.conf


###
###  Clear existing rules, counters, and user-defined chains.
###
  logger "Clearing all firewall rules ..."

  $IPTABLES -F
  $IPTABLES -Z
  $IPTABLES -X
  $IPTABLES -t nat -F
  $IPTABLES -t mangle -F


###
###  Bail (run empty script) if we don't have both $UNTRUSTED_IF and
###  $TRUSTED_IF defined.
###
  if [ -z "$UNTRUSTED_IF" -a -z "$TRUSTED_IF" ]; then
	$USER_SCRIPT
	exit 0
  fi


###
###  If we have $UNTRUSTED_IF and $TRUSTED_NET, then set up masqerading.
###
  if [ -n "$UNTRUSTED_IF" -a -n "$TRUSTED_NET" ]; then
	logger "Setting up IP Masqerading..."

	# Enable forwarding.
	echo 1 > /proc/sys/net/ipv4/ip_forward

	# Masquerade for our internal network ($TRUSTED_NET).
	$IPTABLES -t nat -A POSTROUTING -o $UNTRUSTED_IF -s $TRUSTED_NET -j MASQUERADE
	$IPTABLES -A FORWARD -i $UNTRUSTED_IF -m state --state ESTABLISHED,RELATED -j ACCEPT

	# Set up port forwarding.
	/etc/firewall/include/portfw.sh

	# Load all the IP Masquerading modules if we have $LOAD_MODULES.
	if [ "$LOAD_MODULES" = "yes" ]; then
		modprobe ip_tables
		modprobe ip_conntrack
		modprobe ip_conntrack_ftp
		modprobe ip_conntrack_irc
		modprobe ip_conntrack_pptp
		modprobe ip_nat_ftp
		modprobe ip_nat_irc
		modprobe ip_nat_pptp
		modprobe ip_nat_snmp_basic
		modprobe ip_queue
	fi

	# Block outbound port 80 (www).
	if [ "$NO_OUTBOUND_80" = "yes" ]; then
		$IPTABLES -A FORWARD -p TCP -i $TRUSTED_IF -d 0/0 --dport 80 -j LOG
		$IPTABLES -A FORWARD -p TCP -i $TRUSTED_IF -d 0/0 --dport 80 -j REJECT
	fi

	# We want to perform Traffic Shaping.
	if [ -n "$TC_RATE" ]; then
		/etc/init.d/proxy_tc restart > /dev/null 2>&1
	fi

	# Maybe enforce transparent proxying.
	if [ -n "$TRANSPARENT_PROXY" ] && [ "$TRANSPARENT_PROXY" -gt 0 ]; then
		$IPTABLES -t nat -A PREROUTING -i $TRUSTED_IF -p tcp --dport 80 \
			  -j REDIRECT --to-port $TRANSPARENT_PROXY
	fi
  fi


###
###  If we have $UNTRUSTED_IF, then set up basic firewalling.
###
  if [ ! -z $UNTRUSTED_IF ]; then
	logger "Applying default firewall rules ... "

	# Set default policy on all chains.
	$IPTABLES -P INPUT ACCEPT
	$IPTABLES -P FORWARD ACCEPT
	$IPTABLES -P OUTPUT ACCEPT

	# Allow limited ICMP messages.
	$IPTABLES -A FORWARD -p ICMP -s 0/0 -d 0/0 --icmp-type destination-unreachable -j ACCEPT
	$IPTABLES -A FORWARD -p ICMP -s 0/0 -d 0/0 --icmp-type source-quench -j ACCEPT
	$IPTABLES -A FORWARD -p ICMP -s 0/0 -d 0/0 --icmp-type time-exceeded -j ACCEPT
	$IPTABLES -A FORWARD -p ICMP -s 0/0 -d 0/0 --icmp-type parameter-problem  -j ACCEPT
	$IPTABLES -A FORWARD -p ICMP -s 0/0 -d 0/0 --icmp-type echo-request -j ACCEPT
	$IPTABLES -A FORWARD -p ICMP -s 0/0 -d 0/0 --icmp-type echo-reply -j ACCEPT

	# Block all incoming requests for SMB services on untrusted interface.
	$IPTABLES -A INPUT   -p TCP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 137:139 -j LOG
	$IPTABLES -A INPUT   -p TCP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 137:139 -j REJECT
	$IPTABLES -A FORWARD -p TCP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 137:139 -j LOG
	$IPTABLES -A FORWARD -p TCP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 137:139 -j REJECT
	$IPTABLES -A INPUT   -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 137:139 -j LOG
	$IPTABLES -A INPUT   -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 137:139 -j REJECT
	$IPTABLES -A FORWARD -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 137:139 -j LOG
	$IPTABLES -A FORWARD -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 137:139 -j REJECT

	# Block all incoming requests for DHCP on untrusted interface.
	$IPTABLES -A INPUT   -p TCP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 67:68 -j LOG 
	$IPTABLES -A INPUT   -p TCP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 67:68 -j REJECT
	$IPTABLES -A FORWARD -p TCP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 67:68 -j LOG
	$IPTABLES -A FORWARD -p TCP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 67:68 -j REJECT
	$IPTABLES -A INPUT   -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 67:68 -j LOG
	$IPTABLES -A INPUT   -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 67:68 -j REJECT
	$IPTABLES -A FORWARD -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 67:68 -j LOG
	$IPTABLES -A FORWARD -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 67:68 -j REJECT

	# Block all incoming requests for SYSLOG on untrusted interface.
	$IPTABLES -A INPUT   -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 514 -j LOG
	$IPTABLES -A INPUT   -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 514 -j REJECT
	$IPTABLES -A FORWARD -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 514 -j LOG
	$IPTABLES -A FORWARD -p UDP -i $UNTRUSTED_IF -s 0/0 -d 0/0 --dport 514 -j REJECT

	# Log and block all other packets that make it this far.
	$IPTABLES -A FORWARD -i $UNTRUSTED_IF -j LOG
	$IPTABLES -A FORWARD -i $UNTRUSTED_IF -j REJECT
  fi

# Exit quietly.
exit 0;
